/*
 * RecordForm.java
 *
 * Created on 14. Januar 2005, 13:22
 */



package record;

import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
import javax.microedition.media.control.*;
import javax.microedition.media.*;
import java.io.*;

/**
 * This form shows how the cellphone's microphone can be used to
 * record audio and how the recorded audio can be played on
 * the cellphone.
 * <br><br>
 * This example uses <i>Manager.createPlayer("capture://audio?encoding=amr")</i>
 * because this seems to create the best results on Nokia 6600 cellphones. * 
 * <br><br>
 * On other cellphones try to use <i>Manager.createPlayer("capture://audio")</i>.
 *
 * @author  Alexander De Luca
 * @version 0.9
 *

Copyright (C) 2006 Media Informatics Group (www.mimuc.de), 
University of Munich, Contact person: Enrico Rukzio
(Enrico.Rukzio@ifi.lmu.de)

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


public class RecordForm extends Form implements CommandListener {
    private StringItem messageItem;
    private StringItem errorItem;
    private final Command recordCommand, playCommand;
    private Player p;
    private byte[] recordedSoundArray = null;
    
    public RecordForm() {
        super("Record Audio");
        
        messageItem = new StringItem("Record", "Click record to start recording.");
        this.append(messageItem);
        errorItem = new StringItem("", "");
        this.append(errorItem);
        
        recordCommand = new Command("Record", Command.SCREEN, 1);
        this.addCommand(recordCommand);
        playCommand = new Command("Play", Command.SCREEN, 2);
        this.addCommand(playCommand);
        
        StringBuffer inhalt = new StringBuffer();
        
        this.setCommandListener(this);
    }
    
    public void commandAction(Command comm, Displayable disp) {
        if(comm==recordCommand) {
            try {
                // create the Player object using amr encoding
                p = Manager.createPlayer("capture://audio?encoding=amr");
                p.realize();
                // get the RecordControl over this Player
                RecordControl rc = (RecordControl)p.getControl("RecordControl");
                
                // create an OutputStream which the RecordControl will use
                // to write write the recorded data.
                ByteArrayOutputStream output = new ByteArrayOutputStream();
                rc.setRecordStream(output);
                // start the recording
                rc.startRecord();
                p.start();
                messageItem.setText("recording...");
                Thread.currentThread().sleep(5000); // record for 5 seconds
                messageItem.setText("done!");
                rc.commit();
                // save the recordedData in a byte array
                recordedSoundArray = output.toByteArray();
                // close the player
                p.close();
            } catch (IOException ioe) {
                errorItem.setLabel("Error");
                errorItem.setText(ioe.toString());
            } catch (MediaException me) {
                errorItem.setLabel("Error");
                errorItem.setText(me.toString());
            } catch (InterruptedException ie) {
                errorItem.setLabel("Error");
                errorItem.setText(ie.toString());
            }
        } else if(comm == playCommand) {
            try {
                ByteArrayInputStream recordedInputStream = new ByteArrayInputStream(recordedSoundArray);
                Player p2 = Manager.createPlayer(recordedInputStream,"audio/basic");
                p2.prefetch();
                p2.start();
            }  catch (IOException ioe) {
                errorItem.setLabel("Error");
                errorItem.setText(ioe.toString());
            } catch (MediaException me) {
                errorItem.setLabel("Error");
                errorItem.setText(me.toString());
            }
        }
    }
}
